@@ -4,15 +4,10 @@
 """Lexical analysis of formal languages (i.e. code) using Pygments."""
 
 # :Author: Georg Brandl; Felix Wiemann; Günter Milde
-# :Date: $Date: 2019-08-26 18:46:50 +0200 (Mo, 26. Aug 2019) $
+# :Date: $Date: 2021-01-03 22:05:13 +0100 (So, 03. Jän 2021) $
 # :Copyright: This module has been placed in the public domain.
 
 from docutils import ApplicationError
-try:
-    from pkg_resources import DistributionNotFound as ResourceError
-except (ImportError, RuntimeError):
-    class ResourceError(ApplicationError):
-        pass # stub
 try:
     import pygments
     from pygments.lexers import get_lexer_by_name
@@ -37,7 +32,7 @@ class Lexer(object):
 
       code       -- string of source code to parse,
       language   -- formal language the code is written in,
-      tokennames -- either 'long', 'short', or '' (see below).
+      tokennames -- either 'long', 'short', or 'none' (see below).
 
     Merge subsequent tokens of the same token-type.
 
@@ -47,7 +42,7 @@ class Lexer(object):
       'long':  downcased full token type name,
       'short': short name defined by pygments.token.STANDARD_TYPES
                (= class argument used in pygments html output),
-      'none':      skip lexical analysis.
+      'none':  skip lexical analysis.
     """
 
     def __init__(self, code, language, tokennames='short'):
@@ -66,7 +61,7 @@ class Lexer(object):
                                     'Pygments package not found.')
         try:
             self.lexer = get_lexer_by_name(self.language)
-        except (pygments.util.ClassNotFound, ResourceError):
+        except pygments.util.ClassNotFound:
             raise LexerError('Cannot analyze code. '
                 'No Pygments lexer found for "%s".' % language)
         # self.lexer.add_filter('tokenmerge')
