@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 
 # :Author: Günter Milde <milde@users.sourceforge.net>
-# :Revision: $Revision: 8554 $
-# :Date: $Date: 2020-09-04 18:52:11 +0200 (Fr, 04. Sep 2020) $
+# :Revision: $Revision: 8672 $
+# :Date: $Date: 2021-04-07 14:10:06 +0200 (Mi, 07. Apr 2021) $
 # :Copyright: © 2010 Günter Milde.
 # :License: Released under the terms of the `2-Clause BSD license`_, in short:
 # 
@@ -63,7 +63,7 @@ class Writer(latex2e.Writer):
 
     def __init__(self):
         latex2e.Writer.__init__(self)
-        self.settings_defaults.update({'fontencoding': ''}) # use default (EU1 or EU2)
+        self.settings_defaults.update({'fontencoding': ''}) # use default (TU)
         self.translator_class = XeLaTeXTranslator
 
 
